Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Security Hub.

Actions, resources, and condition keys for AWS Security Hub - Service Authorization Reference

# Actions, resources, and condition keys for AWS Security Hub

AWS Security Hub (service prefix: `securityhub` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Security Hub
- Resource types defined by AWS Security Hub
- Condition keys for AWS Security Hub

## Actions defined by AWS Security Hub

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptInvitation | Grants permission to accept Security Hub invitations to become a member account | Write | hub |  |
BatchDisableStandards | Grants permission to disable standards in Security Hub | Write | hub |  |
BatchEnableStandards | Grants permission to enable standards in Security Hub | Write | hub |  |
BatchImportFindings | Grants permission to import findings into Security Hub from an integrated product | Write | product* |  |
| securityhub:TargetAccount |
BatchUpdateFindings | Grants permission to update customer-controlled fields for a selected set of Security Hub findings | Write | hub |  |
| securityhub:ASFFSyntaxPath/${ASFFSyntaxPath} |
CreateActionTarget | Grants permission to create custom actions in Security Hub | Write | hub |  |
CreateInsight | Grants permission to create insights in Security Hub. Insights are collections of related findings | Write | hub |  |
CreateMembers | Grants permission to create member accounts in Security Hub | Write | hub |  |
DeclineInvitations | Grants permission to decline Security Hub invitations to become a member account | Write | hub |  |
DeleteActionTarget | Grants permission to delete custom actions in Security Hub | Write | hub |  |
DeleteInsight | Grants permission to delete insights from Security Hub | Write | hub |  |
DeleteInvitations | Grants permission to delete Security Hub invitations to become a member account | Write | hub |  |
DeleteMembers | Grants permission to delete Security Hub member accounts | Write | hub |  |
DescribeActionTargets | Grants permission to retrieve a list of custom actions using the API | Read | hub |  |
DescribeHub | Grants permission to retrieve information about the hub resource in your account | Read | hub |  |
DescribeOrganizationConfiguration | Grants permission to describe the organization configuration for Security Hub | Read | hub |  |
DescribeProducts | Grants permission to retrieve information about the available Security Hub product integrations | Read | hub |  |
DescribeStandards | Grants permission to retrieve information about Security Hub standards | Read | hub |  |
DescribeStandardsControls | Grants permission to retrieve information about Security Hub standards controls | Read | hub |  |
DisableImportFindingsForProduct | Grants permission to disable the findings importing for a Security Hub integrated product | Write | hub |  |
DisableOrganizationAdminAccount | Grants permission to remove the Security Hub administrator account for your organization | Write | hub |  |
DisableSecurityHub | Grants permission to disable Security Hub | Write | hub |  |
DisassociateFromMasterAccount | Grants permission to a Security Hub member account to disassociate from the associated master account | Write | hub |  |
DisassociateMembers | Grants permission to disassociate Security Hub member accounts from the associated master account | Write | hub |  |
EnableImportFindingsForProduct | Grants permission to enable the findings importing for a Security Hub integrated product | Write | hub |  |
EnableOrganizationAdminAccount | Grants permission to designate a Security Hub administrator account for your organization | Write | hub |  |
EnableSecurityHub | Grants permission to enable Security Hub | Write | hub |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
GetEnabledStandards | Grants permission to retrieve a list of the standards that are enabled in Security Hub | List | hub |  |
GetFindings | Grants permission to retrieve a list of findings from Security Hub | Read | hub |  |
GetInsightResults | Grants permission to retrieve insight results from Security Hub | Read | hub |  |
GetInsights | Grants permission to retrieve Security Hub insights | List | hub |  |
GetInvitationsCount | Grants permission to retrieve the count of Security Hub membership invitations sent to the account | Read | hub |  |
GetMasterAccount | Grants permission to retrieve details about the Security Hub master account | Read | hub |  |
GetMembers | Grants permission to retrieve the details of Security Hub member accounts | Read | hub |  |
InviteMembers | Grants permission to invite other AWS accounts to become Security Hub member accounts | Write | hub |  |
ListEnabledProductsForImport | Grants permission to retrieve the Security Hub integrated products that are currently enabled | List | hub |  |
ListInvitations | Grants permission to retrieve the Security Hub invitations sent to the account | List | hub |  |
ListMembers | Grants permission to retrieve details about Security Hub member accounts associated with the master account | List | hub |  |
ListOrganizationAdminAccounts | Grants permission to list the Security Hub administrator accounts for your organization | List | hub |  |
ListTagsForResource | Grants permission to list of tags associated with a resource | List | hub* |  |
TagResource | Grants permission to add tags to a Security Hub resource | Write | hub* |  |
UntagResource | Grants permission to remove tags from a Security Hub resource | Write | hub* |  |
UpdateActionTarget | Grants permission to update custom actions in Security Hub | Write | hub |  |
UpdateFindings | Grants permission to update Security Hub findings | Write | hub |  |
UpdateInsight | Grants permission to update insights in Security Hub | Write | hub |  |
UpdateOrganizationConfiguration | Grants permission to update the organization configuration for Security Hub | Write | hub |  |
UpdateSecurityHubConfiguration | Grants permission to update Security Hub configuration | Write | hub |  |
UpdateStandardsControl | Grants permission to update Security Hub standards controls | Write | hub |  |

## Resource types defined by AWS Security Hub

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
hub | `arn:$ { Partition}:securityhub:$ { Region}:$ { Account}:hub/default` | aws:ResourceTag/${TagKey}
product | `arn:$ { Partition}:securityhub:$ { Region}:$ { Account}:product/$ { Company}/$ { ProductId}` |

## Condition keys for AWS Security Hub

AWS Security Hub defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String
securityhub:ASFFSyntaxPath/${ASFFSyntaxPath} | Filters access based on the presence of specific fields and values in the request | String
securityhub:TargetAccount | Filters access based on the presence of AwsAccountId field in the requests | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.